//==============================================================================
//	File:		DarkPassageAPI.h
//
//	Contains: #defines, typedefs, and declarations for Dark Passage C Library API
//
//	Copyright (C) 1992-1995 Apple Computer, Inc.  All rights reserved.
//
//	Change History: (moved to the bottom of this file)
//==============================================================================

#ifndef DPAPI_H
#define DPAPI_H

//==============================================================================
// Dependencies
//==============================================================================

#ifndef __WINDOWS_H
	#ifdef WINDOWS
		#include "windows.h"
	#endif // WINDOWS
#endif // __WINDOWS_H

#ifndef TYPES_H
	#ifdef WINDOWS
		#include "wtypes.h"
	#endif // WINDOWS
	#ifdef MACINTOSH
		#include "types.h"
	#endif // MACINTOSH
#endif // TYPES_H

#ifdef WINDOWS
	#ifndef WFILES_H
		#include "wfiles.h"
	#endif // WFILES_H
#endif // WINDOWS

#ifdef MACINTOSH
	#include "Aliases.h"
#endif 		// MACINTOSH

#ifdef FULL_DOCUMENT
	#ifdef MACINTOSH
		#include "TextEdit.h"
	#endif // MACINTOSH
#endif // FULL_DOCUMENT

#if !defined(TCLOCK_H)
	#include "tclock.h"
#endif


//==============================================================================
// Macros
//==============================================================================

#ifdef WINDOWS
	#define MACCODE(x)
	#define WINCODE(x)	x
#else
	#define MACCODE(x)	x
	#define WINCODE(x)
#endif // WINDOWS

// macro for including code only pertinent to the 1.1 server
#if defined (AS15)
	#define 	AS15CODE(x) x
	#define 	AS10CODE(x)
#else   // 1.0 server
	#define 	AS10CODE(x)	x
	#define 	AS15CODE(x)
#endif

// a couple of handy macros
#define minimumOf( a, b )	(((a)<(b))?(a):(b))
#define maximumOf( a, b )	(((a)>(b))?(a):(b))

// take care of dpapi users
#if !defined (_EXPORT)
	#define _EXPORT
#endif

//==============================================================================
// Constants
//==============================================================================

#ifdef WINDOWS
	#define kWindowClassName				"DarkPassageWindow"

	// used in windows implementation, the .ini file key for finding the default
	// delivery directory for foreign reporter updates.
	#define kDefaultDeliveryDirKey "DefaultDeliveryDir"
#endif // WINDOWS

// errors

#define	kNoError							0

// bit-fields

#define kLogon_AutoLogonFlag			0x00000001
#define kLogon_DeliverUpdateFlag		0x00000002
#define kLogon_IsGuestFlag				0x00000004

// miscellaneous

#define kAlphamericSet \
		"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"

enum IDDataType
{
	kProcessSerialNumber,
	kAEAddressDescriptor,
	kOther
};

#define	kMaximumInfoSourceLength	31
#define 	kMaximumInfoSources			100

#define	kObjType_Reporter				1
#define	kObjType_HitList				2
#define 	kObjType_NewspaperDate		3

#if 0
#define	kObjType_Newspaper			11;
#endif

enum ASRequestKind
{
	kASNullRequest,				// [ 0] void request
	kASEnumSourcesRequest,		// [ 1] retrieve a list of info sources
	kASGetSourceInfoRequest,	// [ 2] open an existing index
	kASOpenSearchRequest,		// [ 3] establish a search session
	kASDoSearchRequest,			// [ 4] perform a search operation
	kASGetRelatedTermsRequest,	// [ 5] expand a search term to list of related terms
	kASCloseSearchRequest,		// [ 6] close a search session
	kASLogoffRequest,	 			// [ 7] retrieve a list of database objects
	kASGetTextRequest,			// [ 8] retrieve text of an article
	kASGetMatchesRequest,		// [ 9] retrieve match list of an article
	kASGetArticleInfoRequest,	// [10] retrieve title and date of an article
	kASGetFileRequest,			// [11] retrieve original article file
	kASAddReporterRequest,		// [12] add a reporter object
	kASModifyReporterRequest,	// [13] modify a reporter object
	kASGetReporterRequest,		// [14] retrieve a reporter object
	kASDeleteReporterRequest,	// [15] remove a reporter object
	kASEnumReporterRequest,		// [16] retrieve a list of reporter objects
	kASImportReporterRequest,	// [17] import a reporter object	.. not yet converted
	kASExportReporterRequest,	// [18] export a reporter object	.. not yet converted
	kASAddObjectRequest,			// [19] add a database object
	kASModifyObjectRequest,		// [20] modify a database object
	kASGetObjectRequest,			// [21] retrieve a database object
	kASDeleteObjectRequest,		// [22] remove a database object
	kASEnumObjectRequest, 		// [23] retrieve a list of database objects

	kASInitializeRequest,   	// [24] Initialize Apple Search
	kASQuitRequest,            // [25] Tear down connections ... quitting
	ASRegisterRequest,         // [26] Register client with Apple Search
	ASUnregisterRequest,       // [27] UnRegister client with Apple Search
	ASLogonRequest,            // [28] Logon to a server
	ASPassLogonDataRequest,    // [29] Obtain logon permissions
	ASLogoffRequest,           // [30] Logoff a server
	ASImportReporterRequest,   // [31] Import a reporter
	ASExportReporterRequest,   // [32] Export a reporter

	#ifdef FULL_DOCUMENT
	, kASOpenReaderRequest, kASGetFullArticleRequest, kASCloseReaderRequest
	#endif	// FULL_DOCUMENT
};




//==============================================================================
// Type Definitions
//==============================================================================

typedef long				ASErr;						// standard error type
typedef long	(PASCAL *ASProcPtr)(char*, long);// completion proc pointer type
																// for all api calls
typedef unsigned long int	ASLogonSessionID;		// server ID for the connection

//==============================================================================
// Parameter Blocks
//
//==============================================================================

//------------------------------------------------------------------------------
// ASParamBlockHeader
//
// AppleSearch Client C API param block standard header
//------------------------------------------------------------------------------

#define ASParamBlockHeader \
	long		userRefCon;					/* for caller's use */					\
	ASErr		error;						/* API call result */					\
	ASProcPtr	completionProc;		/* ptr to a completion routine */	\
	long		registrationID;			/* from ASRegister */


//------------------------------------------------------------------------------
// ASUniversalPB
//------------------------------------------------------------------------------

struct ASUniversalPB
{
	ASParamBlockHeader
};

typedef ASUniversalPB 	ASUniversalPB;
typedef ASUniversalPB*	ASUniversalPBPtr;


//------------------------------------------------------------------------------
// ASRegisterPB
//------------------------------------------------------------------------------

struct ASRegisterPB
{
	ASParamBlockHeader
	long			identifier;
};

typedef ASRegisterPB	ASRegisterPB;
typedef ASRegisterPB*	ASRegisterPBPtr;


//------------------------------------------------------------------------------
// ASSelectServerPB
//------------------------------------------------------------------------------

struct ASSelectServerPB
{
	ASParamBlockHeader
	Ptr				defaultServer;
	unsigned long	dataSize;
	Ptr				dataPtr;
};

typedef ASSelectServerPB 	ASSelectServerPB;
typedef ASSelectServerPB*	ASSelectServerPBPtr;


//------------------------------------------------------------------------------
// ASLogonPB
//------------------------------------------------------------------------------

struct ASLogonPB
{
	ASParamBlockHeader
	unsigned long	flags;			// -> deliverUpdate, autoLogon; <- isGuest
	unsigned long	dataSize;
	Ptr				dataPtr;
	unsigned long	defaultUserNameLength;
	char*				defaultUserNameString;

	AS15CODE(WINCODE(unsigned long	defaultUserPasswordLength;))
	AS15CODE(WINCODE(char*				defaultUserPasswordString;))

	unsigned long	serverNameLength;
	char*				serverNameString;

	AS15CODE(WINCODE(unsigned long	serverPathLength;))
	AS15CODE(WINCODE(char*				serverPath;))    						// zone name
};

typedef ASLogonPB 	ASLogonPB;
typedef ASLogonPB*	ASLogonPBPtr;


//------------------------------------------------------------------------------
// ASLogoffPB
//------------------------------------------------------------------------------

struct ASLogoffPB
{
	ASParamBlockHeader
	Boolean			forceLogoff;
};

typedef ASLogoffPB 	ASLogoffPB;
typedef ASLogoffPB*	ASLogoffPBPtr;


//------------------------------------------------------------------------------
// ASSearchSessionPB
//------------------------------------------------------------------------------

struct ASSearchSessionPB
{
	ASParamBlockHeader
	long searchSessionID;
};

typedef ASSearchSessionPB 	ASSearchSessionPB;
typedef ASSearchSessionPB*	ASSearchSessionPBPtr;


//------------------------------------------------------------------------------
// ASDBObjectInfo
//------------------------------------------------------------------------------

struct ASDBObjectInfo
{
	long				dbObjectID;
#if 0
	Str31				dbObjectName;
#endif
	long				dbObjectFlags;
	unsigned long	dbObjectNameLength;
	char*				dbObjectNameString;
};

typedef ASDBObjectInfo 	ASDBObjectInfo;
typedef ASDBObjectInfo*	ASDBObjectInfoPtr;


//------------------------------------------------------------------------------
// ASEnumeratePB
//------------------------------------------------------------------------------

struct ASEnumeratePB
{
	ASParamBlockHeader
	long					dbObjectType;
	unsigned long		numberOfDBObjects;// number of objects in the list
	ASDBObjectInfoPtr	dbObjectList;		// an array of ASDBObjectInfo structures
};

typedef	ASEnumeratePB 	ASEnumeratePB;
typedef ASEnumeratePB*	ASEnumeratePBPtr;


//------------------------------------------------------------------------------
// ASHitInfo
//------------------------------------------------------------------------------

struct ASHitInfo
{
	long				articleID;
	long				modDate;
	unsigned long	fileSize;
	unsigned long	rank;
	unsigned long	titleLength;
	char*				titleString;
};

typedef ASHitInfo 	ASHitInfo;
typedef ASHitInfo*	ASHitInfoPtr;


//------------------------------------------------------------------------------
// ASSearchPB
//------------------------------------------------------------------------------

struct ASSearchPB
{
	ASParamBlockHeader
	long				searchSessionID;
	long				sourceID;
	unsigned long	queryLength;
	char*				queryString;		// c string, null terminated
	unsigned long	minimumRank;
	unsigned long	maximumHits;		// NOTE: who allocates the memory for hits?
	long				earliestModDate;
	long				searchType;
	long				searchID;
	unsigned long	numberOfHitsReturned;
	unsigned long	totalNumberOfHits;
	ASHitInfoPtr*	hitList;				// packed array of ASHitPtrs
};

typedef ASSearchPB 	ASSearchPB;
typedef ASSearchPB*	ASSearchPBPtr;


//------------------------------------------------------------------------------
// ASGetArticleInfoPB
//------------------------------------------------------------------------------

struct ASGetArticleInfoPB
{
	ASParamBlockHeader
	long				sourceID;
	long				articleID;
	long				modDate;
	unsigned long	size;
	unsigned long	titleLength;
	char*				titleString;
};

typedef	ASGetArticleInfoPB 	ASGetArticleInfoPB;
typedef ASGetArticleInfoPB*	ASGetArticleInfoPBPtr;


//------------------------------------------------------------------------------
// ASGetArticleTextPB
//------------------------------------------------------------------------------

struct ASGetArticleTextPB
{
	ASParamBlockHeader
	long				searchSessionID;
	long				sourceID;
	long				articleID;
	unsigned long	startOffset;
	unsigned long	length;
	AS10CODE(MACCODE(Handle	text;))
	AS10CODE(WINCODE(Handle	text;))
	AS15CODE(WINCODE(char 	*text;))
};

typedef ASGetArticleTextPB	ASGetArticleTextPB;
typedef ASGetArticleTextPB*	ASGetArticleTextPBPtr;


//------------------------------------------------------------------------------
// ASGetArticleMatchesPB
//------------------------------------------------------------------------------

struct ASGetArticleMatchesPB
{
	ASParamBlockHeader
	long				searchSessionID;
	long				sourceID;
	long				articleID;
	unsigned long	startOffset;
	unsigned long	length;
	unsigned long	numberOfHiliteInfoRecs;
	long*				hiliteInfo; // points to first long of array of hiliteinfoRecs
};

typedef ASGetArticleMatchesPB	ASGetArticleMatchesPB;
typedef ASGetArticleMatchesPB*	ASGetArticleMatchesPBPtr;


//------------------------------------------------------------------------------
// ASHiliteInfoRec
//------------------------------------------------------------------------------

struct ASHiliteInfoRec
{
	unsigned long	offset;
	unsigned long	length;
};

typedef ASHiliteInfoRec 	ASHiliteInfoRec;
typedef ASHiliteInfoRec*	ASHiliteInfoRecPtr;


//------------------------------------------------------------------------------
// ASGetOriginalFilePB
//------------------------------------------------------------------------------

struct	ASGetOriginalFilePB
{
	ASParamBlockHeader
	long										sourceID;
	long										articleID;
	WINCODE(long							flags;)		// reserved - initialized to 0
	MACCODE(long							flags;)		// 1=original file; 2=file alias
	AS10CODE(MACCODE(FSSpec				fileDestination;))
	AS15CODE(MACCODE(FSSpec				fileDestination;))
	AS10CODE(MACCODE(AliasHandle		alias;))
	AS15CODE(MACCODE(AliasHandle		alias;))

	AS10CODE(WINCODE(FSSpec				fileDestination;))
	AS10CODE(WINCODE(AliasHandle		alias;))
	AS15CODE(WINCODE(unsigned long	fileDestLength;))
	AS15CODE(WINCODE(char				*fileDestination;))
};

typedef ASGetOriginalFilePB 	ASGetOriginalFilePB;
typedef ASGetOriginalFilePB*	ASGetOriginalFilePBPtr;


//------------------------------------------------------------------------------
// ASReporterPB
//------------------------------------------------------------------------------

struct ASReporterPB
{
	ASParamBlockHeader
	long				reporterID;
	unsigned long	nameLength;
	char*				nameString;

	// search parameters

	unsigned long	queryLength;
	char*				queryString;			// c string, null terminated
	unsigned long	minimumRank;
	unsigned long	maximumHits;
	long				earliestModDate;
	long				earliestIndexDate;
	unsigned long	numberOfSources;
	long*				sourceList;

	// scheduling info

	unsigned long	deliveryDays;
	unsigned long	deliveryTime;
	long				deliveryFlags;
	unsigned long	deliveryDirLength;
	AS10CODE(MACCODE(AliasPtr	deliveryDir;))
	AS10CODE(WINCODE(AliasPtr	deliveryDir;))
	AS15CODE(WINCODE(char 		*deliveryDir;))
};

typedef	ASReporterPB 	ASReporterPB;
typedef ASReporterPB*	ASReporterPBPtr;


//----------------------------------------------------------------------------------------------------
// ASDBObjectPB
//----------------------------------------------------------------------------------------------------

struct ASDBObjectPB
{
	ASParamBlockHeader
	long				dbObjectType;
	ASDBObjectInfo	dbObjectInfo;
	long				sourceID;				// used only if type is hit list
	unsigned long	dbObjectDataSize;
	Ptr				dbObjectData;
};

typedef ASDBObjectPB 	ASDBObjectPB;
typedef ASDBObjectPB*	ASDBObjectPBPtr;


//------------------------------------------------------------------------------
// ASImportExportPB
//------------------------------------------------------------------------------

struct ASImportExportPB
{
	ASParamBlockHeader
	AS15CODE(WINCODE(unsigned long 	reporterFileLength;))
	AS15CODE(WINCODE(char				*reporterFile;))	// reporter file nm  - full path
	AS15CODE(MACCODE(FSSpec				reporterFile;))
	AS10CODE(MACCODE(FSSpec				reporterFile;))
	AS10CODE(WINCODE(FSSpec				reporterFile;))
	long										reporterID;
	unsigned long							nameLength;
	char*										nameString;
};

typedef	ASImportExportPB 	ASImportExportPB;
typedef ASImportExportPB*	ASImportExportPBPtr;


//------------------------------------------------------------------------------
// ASGetRelatedTermsPB
//------------------------------------------------------------------------------

struct ASGetRelatedTermsPB
{
	ASParamBlockHeader
	long				sourceID;
	unsigned long	queryLength;
	char*				queryString;
	unsigned long	maximumTerms;
	unsigned long	numberOfTerms;
	StringPtr*		termList;
};

typedef	ASGetRelatedTermsPB 	ASGetRelatedTermsPB;
typedef ASGetRelatedTermsPB*	ASGetRelatedTermsPBPtr;


//------------------------------------------------------------------------------
// ASGetSourceInfoPB
//------------------------------------------------------------------------------

struct ASGetSourceInfoPB
{
	ASParamBlockHeader
	long				sourceID;
	unsigned long	numberOfDocsIndexed;
	unsigned long	indexFileSize;
	unsigned long	textSizeIndexed;
	unsigned long	lastIndexedDate;
	Str255			description;
};

typedef	ASGetSourceInfoPB 	ASGetSourceInfoPB;
typedef 	ASGetSourceInfoPB*	ASGetSourceInfoPBPtr;


//------------------------------------------------------------------------------
// ASDeliverUpdatesNowPB
//------------------------------------------------------------------------------

struct ASDeliverUpdatesNowPB
{
	ASParamBlockHeader                     // in: final callback defined here
	long				flags;     					// in: bit 0 - call completionProc
														// with interim results
														//	out: bit 1, delivery complete
	char*				currReporter;				// out: current reporter name
	long				articleCntThisReporter;	// out: count of new articles this
														// reporter
};

typedef	ASDeliverUpdatesNowPB 	ASDeliverUpdatesNowPB;
typedef 	ASDeliverUpdatesNowPB*	ASDeliverUpdatesNowPBPtr;


//------------------------------------------------------------------------------
// ASArticleReaderPB
//------------------------------------------------------------------------------

#ifdef FULL_DOCUMENT
struct ASArticleReaderPB
{
	ASParamBlockHeader
	long			readerID;
	long			sourceID;
	long			articleID;
};

typedef	ASArticleReaderPB 	ASArticleReaderPB;
typedef ASArticleReaderPB*		ASArticleReaderPBPtr;
#endif	// FULL_DOCUMENT


//------------------------------------------------------------------------------
// ASGetFullArticlePB
//------------------------------------------------------------------------------

#ifdef FULL_DOCUMENT
struct ASGetFullArticlePB
{
	ASParamBlockHeader
	long			readerID;
	long			flags;					// if byte 0 is 1, call ASGetFullArticle()
												//	again for more data
	long			fullTextLength;		// size of Handle
	Handle		fullText;
};

typedef ASGetFullArticlePB	ASGetFullArticlePB;
typedef ASGetFullArticlePB*	ASGetFullArticlePBPtr;
#endif	// FULL_DOCUMENT


//------------------------------------------------------------------------------
// ASFullArticleHeader
//
// Header for fullText of first full document request (subsequently embedded in data).
//------------------------------------------------------------------------------

#ifdef FULL_DOCUMENT
struct ASFullArticleHeader
{
	OSType		runType;			// type of following data chunk
	long			runDataLength;	// length of following data chunk (not counting
										// this header).  Data may be split across fullText
										//	handles returned in ASGetFullArticlePB.
	TextStyle	style;			// defined in TextEdit.h
	short			justification;
	short			flags;		  	// bit 0 set if 1 byte padding follows data
};

typedef ASFullArticleHeader	ASFullArticleHeader;
typedef ASFullArticleHeader*	ASFullArticleHeaderPtr;
#endif	// FULL_DOCUMENT

#if defined (WINDOWS)
//	Windows-style declarations for the control blks
typedef ASUniversalPB 	 		_far *LPASUNIVERSALPB;
typedef ASRegisterPB 			_far *LPASREGISTERPB;
typedef ASSelectServerPB 		_far *LPASSELECTSERVERPB;
typedef ASLogonPB 				_far *LPASLOGONPB;
typedef ASLogoffPB 				_far *LPASLOGOFFPB;
typedef ASSearchSessionPB	  	_far *LPASSEARCHSESSIONPB;
typedef ASDBObjectInfo 			_far *LPASDBOBJECTINFO;
typedef ASEnumeratePB 			_far *LPASENUMERATEPB;
typedef ASHitInfo 				_far *LPASHITINFO;
typedef ASSearchPB 				_far *LPASSEARCHPB;
typedef ASGetArticleInfoPB	 	_far *LPASGETARTICLEINFOPB;
typedef ASGetArticleTextPB 	_far *LPASGETARTICLETEXTPB;
typedef ASGetArticleMatchesPB _far *LPASGETARTICLEMATCHESPB;
typedef ASHiliteInfoRec 		_far *LPASHILITEINFOREC;
typedef ASGetOriginalFilePB 	_far *LPASGETORIGINALFILEPB;
typedef ASReporterPB 		  	_far *LPASREPORTERPB;
typedef ASDBObjectPB 			_far *LPASDBOBJECTPB;
typedef ASImportExportPB 		_far *LPASIMPORTEXPORTPB;
typedef ASGetRelatedTermsPB 	_far *LPASGETRELATEDTERMSPB;
typedef ASGetSourceInfoPB 		_far *LPASGETSOURCEINFOPB;
typedef ASDBObjectInfo 			_far *LPASDBOBJECTINFO;
typedef ASDeliverUpdatesNowPB	_far *LPASDELIVERUPDATESNOWPB;
#endif

//==============================================================================
// Function Prototypes
//==============================================================================

#ifdef __cplusplus
extern "C"
{
#endif

//------------------------------------------------------------------------------
// "House keeping" routines
//------------------------------------------------------------------------------

void	_EXPORT PASCAL ASInitialize(void); 	// must be called to initialize internal globals
void	_EXPORT PASCAL ASQuit(void);   		// called when your application is ready to quit

//
//	The 1.0 version of the Windows version of AS requires that the registration
//	id returned from ASRegister be passed to the DoIdle(long) function.  When
//	a client is not registered with DP, the client has no need to call DoIdle(long),
//	or if they prefer, pass a 0 as the argument value when not logged on. 
//
//	The 1.1 version of the Mac takes no argument.

MACCODE(ASErr	PASCAL ASDoIdle(void);)	// called in each waitNextEvent loop iteration
WINCODE(ASErr	_EXPORT PASCAL ASDoIdle(long regID);) // call each WINMAIN msg loop iteration
MACCODE(ASErr	PASCAL ASRegister(ASRegisterPBPtr pb);)
WINCODE(ASErr	_EXPORT PASCAL ASRegister(HWND hwndApp, HWND hwndHelp, ASRegisterPBPtr pb);)
ASErr	_EXPORT PASCAL ASUnregister(ASRegisterPBPtr pb);
ASErr	_EXPORT PASCAL ASSelectServer(ASSelectServerPBPtr pb);
ASErr	_EXPORT PASCAL ASLogon(ASLogonPBPtr pb);
ASErr	_EXPORT PASCAL ASLogoff(ASLogoffPBPtr pb);

//BEGINPRIVATE: this is a private function to DarkPassage, not a part of published API
ASErr	_EXPORT PASCAL ASGetSourceInfo	(ASGetSourceInfoPBPtr pb, Boolean async);
//ENDPRIVATE


//------------------------------------------------------------------------------
// Search routines
//------------------------------------------------------------------------------

ASErr	_EXPORT PASCAL ASOpenSearchSession(ASSearchSessionPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASCloseSearchSession(ASSearchSessionPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASSearch(ASSearchPBPtr pb, Boolean async);


//------------------------------------------------------------------------------
// Data retrieval routines
//------------------------------------------------------------------------------

ASErr	_EXPORT PASCAL ASEnumerateSources(ASEnumeratePBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetArticleText(ASGetArticleTextPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetArticleMatches(ASGetArticleMatchesPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetArticleInfo(ASGetArticleInfoPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetOriginalFile(ASGetOriginalFilePBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetRelatedTerms(ASGetRelatedTermsPBPtr pb, Boolean async);

ASErr _EXPORT PASCAL ASDeliverUpdatesNow(ASDeliverUpdatesNowPBPtr pb, Boolean async);

//------------------------------------------------------------------------------
// Reporter routines
//------------------------------------------------------------------------------

ASErr	_EXPORT PASCAL ASAddReporter(ASReporterPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASModifyReporter(ASReporterPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetReporter(ASReporterPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASDeleteReporter(ASReporterPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASEnumerateReporters(ASEnumeratePBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASImportReporter(ASImportExportPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASExportReporter(ASImportExportPBPtr pb, Boolean async);


//------------------------------------------------------------------------------
// DBObject routines
//------------------------------------------------------------------------------

ASErr	_EXPORT PASCAL ASAddDBObject(ASDBObjectPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASModifyDBObject(ASDBObjectPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetDBObject(ASDBObjectPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASDeleteDBObject(ASDBObjectPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASEnumerateDBObjects(ASEnumeratePBPtr pb, Boolean async);


//------------------------------------------------------------------------------
// Full document routines
//------------------------------------------------------------------------------

#ifdef FULL_DOCUMENT
ASErr	_EXPORT PASCAL ASOpenArticleReader(ASArticleReaderPBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASGetFullArticle(ASGetFullArticlePBPtr pb, Boolean async);
ASErr	_EXPORT PASCAL ASCloseArticleReader(ASArticleReaderPBPtr pb, Boolean async);
#endif	// FULL_DOCUMENT



#ifdef __cplusplus
}
#endif


#endif // DPAPI_H

//
// Change History:
//
//		Date		By		Description
//		----		--		-----------
//		93/12/14	JPS		Added typedef for ASLogonSessionID.
//
// Change History:
//
//		Date		By		Description
//		----		--		-----------
//		03/31/94	SW		Added {#include "windows.h"}.
//
//
// $Log: /bogart/dp/shared/DPAPI.H $
//
// 36    4/04/95 1:51p Rjohnson
//

