/*====================================================================================================
	File: WTYPES.H

	Copyright (C) 1994-1995 Apple Computer, Inc.  All rights reserved.

	Description:

		C Interface to the Macintosh Libraries

	History:

		Date		By		Description
		----		--		-----------
		03/31/94	SW		smRoman - added.
====================================================================================================*/

#if !defined(__WTYPES__) || !defined(__TYPES__) || !defined(TYPES_H)
#define __WTYPES__
#define __TYPES__
#define TYPES_H

#if defined __cplusplus
extern "C" {
#endif

//
// constants
//

#ifndef SystemSevenOrLater
#define SystemSevenOrLater 0
#endif

#ifndef SystemSixOrLater
#define SystemSixOrLater SystemSevenOrLater
#endif


#define smSystemScript -1


//----------------------------------------------------------------------------------------------------
// Macros - NULL, nil, noErr, AuxOut
//----------------------------------------------------------------------------------------------------

#ifndef NULL
#define NULL 	0
#endif
#ifndef nil
#define nil 	0
#endif

#define noErr 	0

// OUT_DBG_STR macro surrounds OutputDebugString stmts.  If OutputDebugString()
//	functions are to be used in the debug environment, one should define
//	this macro.
#if defined (OUT_DBG_STR)
	#define OutDbgStr(x) x
#else
	#define OutDbgStr(x)
#endif


//----------------------------------------------------------------------------------------------------
// Basic data types
//----------------------------------------------------------------------------------------------------

typedef unsigned char 	Byte;
typedef char 			SignedByte;
typedef char*			Ptr;
typedef Ptr*			Handle;    // pointer to a master pointer
typedef long 			Fixed;     /* fixed point arithmatic type */
typedef Fixed*			FixedPtr;
typedef long 			Fract;
typedef Fract*			FractPtr;

enum
{
	false,
	true
};

typedef unsigned char Boolean;

enum
{
	v,
	h
};

typedef unsigned char VHSelect;

// procedures

typedef long 			(*ProcPtr)();
typedef ProcPtr*		ProcHandle;

// strings

typedef unsigned char 	Str255[256];
typedef unsigned char	Str63[64];
typedef unsigned char	Str32[33];
typedef unsigned char	Str31[32];
typedef unsigned char	Str27[28];
typedef unsigned char	Str15[16];
typedef unsigned char*	StringPtr;
typedef unsigned char**	StringHandle;

#ifdef __cplusplus
inline unsigned char& 	Length(StringPtr string)
							{ return (*string); }
#else
#define Length(string) (*(unsigned char *)(string))
#endif

typedef const unsigned char*	ConstStr255Param;
typedef ConstStr255Param 		ConstStr63Param;
typedef ConstStr255Param 		ConstStr32Param;
typedef ConstStr255Param 		ConstStr31Param;
typedef ConstStr255Param 		ConstStr27Param;
typedef ConstStr255Param 		ConstStr15Param;

typedef short 			OSErr;
typedef unsigned long 	OSType;
typedef OSType*			OSTypePtr;
typedef unsigned long 	ResType;
typedef ResType*		ResTypePtr;
typedef unsigned char 	Style;
typedef short 			ScriptCode;
typedef short 			LangCode;

struct Point
{
	short v;
	short h;
};

typedef struct Point	Point;
typedef Point*			PointPtr;

struct Rect
{
	short top;
	short left;
	short bottom;
	short right;
};

typedef struct Rect	Rect;
typedef Rect*		RectPtr;

//
//	from Packages.h actually
//

typedef unsigned char  DateForm;
// DateForm's values
enum DateFormConsts
{
	shortDate 	=	0,
	longDate		=	1,
	abbrevDate	=	2
};

//
//	from OSUtils.h actually
//

struct DateTimeRec {
    short year;
    short month;
    short day;
    short hour;
    short minute;
    short second;
    short dayOfWeek;
};

typedef struct DateTimeRec DateTimeRec;


//----------------------------------------------------------------------------------------------------
// Miscellaneous Constants
//----------------------------------------------------------------------------------------------------




#if defined(__cplusplus)

// In MPW, HandleObject is a built-in class supported by a
//	non-portable language extension.

class HandleObject
{
};

#endif // __cplusplus

// STR2CHAR4(x) -- in most Mac compilers, 4-byte character constants of the form 'xxxx' are accepted but most
// PC compilers don't recognize this format.  The CHAR4 macro provides a portable way to deal with 4-byte
// character constants.  For example:
//
//		unsigned long x = 'Cool';						// works only on Mac
//		unsigned long y = CHAR4("Cool");				// works on both Mac and PC

#define STR2CHAR4(s) *((unsigned long *)(s))


#if defined __cplusplus
}
#endif




#endif // __TYPES__

//
// $Log: /bogart/mac/shared/WTYPES.H $
// 
// 21    8/23/94 9:52p Rich_johnson
//

